#
# spec file for package python-fire
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-fire
Version:        0.5.0
Release:        1.8
Summary:        A library for automatically generating command line interfaces
License:        Apache-2.0
URL:            https://github.com/google/python-fire
Source:         https://files.pythonhosted.org/packages/source/f/fire/fire-%{version}.tar.gz
# Based on https://github.com/google/python-fire/pull/265/files
Patch0:         python-fire-no-mock.patch
Patch1:         support-python-311.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
Requires:       python-termcolor
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Levenshtein}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module termcolor}
# /SECTION
%python_subpackages

%description
Python Fire is a library for automatically generating command line
interfaces (CLIs) from a Python object.

%prep
%autosetup -p1 -n fire-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Feb  7 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.0:
  * Support for custom serializers with fire.Fire(serializer=your_serializer)
  * Auto-generated help text now shows short arguments (e.g. -a) when
    appropriate
  * Default values are now shown in help for kwonly arguments
  * Completion script fix where previously completions might not show at all
- Refresh python-fire-no-mock.patch
- Add patch support-python-311.patch:
  * Support Python 3.11
* Wed Mar 16 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/google/python-fire/pull/265/files
  + python-fire-no-mock.patch
* Fri Mar 12 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.0:
  * Support for Python 3.8 and Python 3.9
  * Argument types and defaults appear in help text
  * Support for asyncio coroutines
  * Support for modules and Python files with python -m fire
  * Keyword argument info from rst docstrings appears in help text
  * Bug fix for missing parts of multiline argument descriptions from
    Google and Numpy style docstrings.
  * Support functions even when they override getattr in non-standard ways.
- Drop patch subpoint-usage-test.patch, which is no longer required.
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.1:
  * Removes preexec_fn from pager subprocess cal
* Thu Apr  2 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.3.0:
  * Use Fire on third-party code without making any code changes:
    python -m fire <module>
  * Docstring parsing fix for all lines are blank f01aad3
  * Improved parsing of numpy-style docstrings
  * #187 Expose built-in functions from the standard library (e.g. sin, cos)
  * #149 Support objects implementing __getattr__
  * #205 Fix ctrl-C handling in help screens
  * Support functools.wraps and lru_cache decorated functions
  * Better support for objects with properties
  * Objects with custom __str__ are now treated as Values. E.g. If such an
    object appears in a dict, the dict will still print in line-by-line mode
    rather than showing a help screen by default.
  * Formatting on Windows works properly now
* Tue Oct 15 2019 Steve Kowalik <steven.kowalik@suse.com>
- Add subpoint-usage-test.patch, which will change the subpoint usage string
  if running under Python 3.8.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.1:
  * Improves robustness of docstring parser in the face of unexpected format docstrings. #183
* Tue Jul 30 2019 pgajdos@suse.com
- version update to 0.2.0
  * Help and usage screens
  * Help screens now have a man-page appearance and are shown with less-style pagination. Usage screens are shown when a user-error is encountered. The help and usage screens are considerably cleaner than the default output in previous versions of Fire.
  * Custom serialization
  * If you define a custom __str__ method on an object, that will be used to serialize the object when it is the final result of a Fire command. This means better support for numpy arrays, and better support for custom types.
  * Docstring parsing
  * Notably, docstrings are parsed in order to determine the descriptions to use for arguments in the help screens. We largely support (but not fully) Google, numpy, and RST style docstrings. These are the three most common styles of docstring used in Python code.
  * Access --help naturally
  * You no longer need to separate --help from your command with an extra --. Simply running command -h or command --help will give help, provided there isn't an argument named help in your component.
  * NamedTuples can be indexed both by their field names and by their indexes.
  * Callable objects can both be called, and their members can be accessed.
  * You must use flag syntax to call a callable object; you cannot pass their arguments positionally.
  * Single-hyphen flags are supported
  * You can now specify -flag instead of --flag if preferred. Both work.
  * Short-flags are permitted when their use is unambiguous
  * E.g. if your function has argument alpha, then you can specify its value with -a.
  * Fish completion support
- deleted patches
  - fix-issue-164.patch (upstreamed)
* Fri Mar  8 2019 Matej Cepl <mcepl@suse.com>
- Add fix-issue-164.patch patch to fix gh#google/python-fire#164
  and we can run whole test suite.
* Thu Feb  7 2019 Matej Cepl <mcepl@suse.com>
- Switch of tests testFireKeywordArgs, testFireObjectWithDict,
  testHelpStringBuiltin, and testGetFullArgSpecFromBuiltin
  gh#google/python-fire#164
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Simplify the tests call
* Thu Nov 15 2018 Todd R <toddrme2178@gmail.com>
- Initial version
